searchData={"items":[{"type":"task","doc":"Downloads the required Unicode Unihan database to support\nUnihan introspection.","title":"mix unicode.unihan.download","ref":"Mix.Tasks.Unicode.Unihan.Download.html"},{"type":"module","doc":"Functions to introspect the Unicode Unihan character database.","title":"Unicode.Unihan","ref":"Unicode.Unihan.html"},{"type":"function","doc":"Filter the Unihan database returning selected\ncodepoints.","title":"Unicode.Unihan.filter/1","ref":"Unicode.Unihan.html#filter/1"},{"type":"function","doc":"* `fun` is a `1-arity` function that is passed\n  the attribute map for a given codepoint. if the\n  function returns a `truthy` value then the codepoint\n  is included in the returned data. If the return\n  value is `falsy` then the codepoint is omitted\n  from the returned list.","title":"Arguments - Unicode.Unihan.filter/1","ref":"Unicode.Unihan.html#filter/1-arguments"},{"type":"function","doc":"* a map of the filtered codepoints mapped to their\n  attributes.","title":"Returns - Unicode.Unihan.filter/1","ref":"Unicode.Unihan.html#filter/1-returns"},{"type":"function","doc":"iex> Unicode.Unihan.filter(&(&1.kTotalStrokes[:\"Hans\"] > 30))\n    ...> |> Enum.count()\n    238\n\n    iex> Unicode.Unihan.filter(&(&1.kTotalStrokes[:\"Hans\"] != &1.kTotalStrokes[:\"Hant\"]))\n    ...> |> Enum.count\n    3\n\n    iex> Unicode.Unihan.filter(&(&1[:kGradeLevel] <= 6))\n    ...> |> Enum.count\n    2632","title":"Example - Unicode.Unihan.filter/1","ref":"Unicode.Unihan.html#filter/1-example"},{"type":"function","doc":"Load the unihan data into :persistent_term.\n\nThis function will be called on the first access\nby `Unicode.Unihan.unihan/1` but can be called\non application load if required.\n\nFirst the existence of an erlang term format\nfile of the unihan database is found. If so,\nit is loaded. If not (the first time the function\nis called), the file is generated and then loaded.","title":"Unicode.Unihan.load_unihan/0","ref":"Unicode.Unihan.html#load_unihan/0"},{"type":"function","doc":"Filter the Unihan database returning selected\ncodepoints that are not rejected by the provided\nfunction.","title":"Unicode.Unihan.reject/1","ref":"Unicode.Unihan.html#reject/1"},{"type":"function","doc":"* `fun` is a `1-arity` function that is passed\n  the attribute map for a given codepoint. if the\n  function returns a `falsy` value then the codepoint\n  is included in the returned data. If the return\n  value is `truthy` then the codepoint is omitted\n  from the returned list.","title":"Arguments - Unicode.Unihan.reject/1","ref":"Unicode.Unihan.html#reject/1-arguments"},{"type":"function","doc":"* a map of the codepoints that are not rejected\n  mapped to their attributes.","title":"Returns - Unicode.Unihan.reject/1","ref":"Unicode.Unihan.html#reject/1-returns"},{"type":"function","doc":"iex> Unicode.Unihan.reject(&(&1.kTotalStrokes[:\"Hans\"] > 30))\n    ...> |> Enum.count()\n    98444","title":"Example - Unicode.Unihan.reject/1","ref":"Unicode.Unihan.html#reject/1-example"},{"type":"function","doc":"Takes an integer codepoint, a Unihan codepoint map, or list of maps\nand returns the grapheme (or list of graphemes)\nof the codepoint.","title":"Unicode.Unihan.to_string/1","ref":"Unicode.Unihan.html#to_string/1"},{"type":"function","doc":"iex> Unicode.Unihan.to_string(25342)\n    \"拾\"\n\n    iex> Unicode.Unihan.unihan(\"拾\")\n    ...> |> Unicode.Unihan.to_string()\n    \"拾\"","title":"Examples - Unicode.Unihan.to_string/1","ref":"Unicode.Unihan.html#to_string/1-examples"},{"type":"function","doc":"Returns the Unihan database metadata for\na given codepoint.\n\nThe codepoint can be expressed as an integer\nor a grapheme.","title":"Unicode.Unihan.unihan/1","ref":"Unicode.Unihan.html#unihan/1"},{"type":"function","doc":"iex> Unicode.Unihan.unihan(171339)\n    %{\n      codepoint: 171339,\n      kTotalStrokes: %{Hant: 11, Hans: 11},\n      kCantonese: %{\n        final: \"u\",\n        jyutping: \"ju4\",\n        coda: \"\",\n        nucleus: \"u\",\n        onset: \"j\",\n        tone: \"4\"\n      },\n      kDefinition: [\"(J) nonstandard variant of 魚 U+9B5A, fish\"],\n      kHanYu: %{position: 9, virtual: false, page: 4674, volume: 7},\n      kIRG_GSource: %{source: \"GHZ\", mapping: [\"74674.09\"]},\n      kIRG_TSource: %{source: \"T4\", mapping: \"3043\"},\n      kIRG_VSource: %{source: \"VN\", mapping: \"29D4B\"},\n      kIRGHanyuDaZidian: %{position: 9, virtual: false, page: 4674, volume: 7},\n      kIRGKangXi: %{position: 1, virtual: true, page: 1465},\n      kJapaneseKun: [\"UO\", \"SAKANA\", \"SUNADORU\"],\n      kJapaneseOn: \"GYO\",\n      kKangXi: %{position: 1, virtual: true, page: 1465},\n      kMorohashi: %{index: 45958, prime: \"\"},\n      kNelson: 692,\n      kPhonetic: %{class: 1605},\n      kRSAdobe_Japan1_6: [\n        %{\n          code: \"C\",\n          cid: 13717,\n          kangxi: 195,\n          strokes_radical: 10,\n          strokes_residue: 0\n        },\n        %{\n          code: \"V\",\n          cid: 13718,\n          kangxi: 195,\n          strokes_radical: 10,\n          strokes_residue: 0\n        }\n      ],\n      kRSUnicode: %{radical: 195, strokes: 0, simplified_radical: false},\n      kJapanese: [\"ギョ\", \"うお\"],\n      kMojiJoho: \"MJ055080\"\n    }\n\n    iex> Unicode.Unihan.unihan(\"㝰\")\n    %{\n      codepoint: 14192,\n      kTotalStrokes: %{Hant: 18, Hans: 18},\n      kCangjie: [\"J\", \"H\", \"U\", \"S\"],\n      kCantonese: %{\n        final: \"in\",\n        jyutping: \"min4\",\n        coda: \"n\",\n        nucleus: \"i\",\n        onset: \"m\",\n        tone: \"4\"\n      },\n      kDefinition: [\"unable to meet, empty room\"],\n      kHanYu: %{position: 3, virtual: false, page: 957, volume: 2},\n      kHanyuPinyin: %{\n        location: [%{position: 3, virtual: false, page: 20957}],\n        readings: [\"mián\"]\n      },\n      kIRG_GSource: %{source: \"G5\", mapping: [\"3E3C\"]},\n      kIRG_KSource: %{source: \"K3\", mapping: \"236A\"},\n      kIRG_TSource: %{source: \"T4\", mapping: \"5A7D\"},\n      kIRGHanyuDaZidian: %{position: 3, virtual: false, page: 957, volume: 2},\n      kIRGKangXi: %{position: 1, virtual: false, page: 293},\n      kKangXi: %{position: 1, virtual: false, page: 293},\n      kMandarin: \"mián\",\n      kMorohashi: %{index: 7359, prime: \"\"},\n      kRSUnicode: %{radical: 40, strokes: 15, simplified_radical: false},\n      kSBGY: %{position: 35, page: 135},\n      kJapanese: [\"ベン\", \"メン\"],\n      kMojiJoho: \"MJ000772\"\n    }","title":"Examples - Unicode.Unihan.unihan/1","ref":"Unicode.Unihan.html#unihan/1-examples"},{"type":"function","doc":"Returns the property information for the data in the\nUnihan database.","title":"Unicode.Unihan.unihan_properties/0","ref":"Unicode.Unihan.html#unihan_properties/0"},{"type":"module","doc":"Allow easy interconversion of keyboard input and character.","title":"Unicode.Unihan.Cangjie","ref":"Unicode.Unihan.Cangjie.html"},{"type":"function","doc":"Converts an alphabet keyboard input to the Chinese Cangjie part.  Returns an OK tuple.","title":"Unicode.Unihan.Cangjie.cangjie/1","ref":"Unicode.Unihan.Cangjie.html#cangjie/1"},{"type":"function","doc":"iex> Unicode.Unihan.Cangjie.cangjie(\"U\")\n    {:ok, \"山\"}","title":"Example - Unicode.Unihan.Cangjie.cangjie/1","ref":"Unicode.Unihan.Cangjie.html#cangjie/1-example"},{"type":"function","doc":"Converts an alphabet keyboard input, or a list of alphabet keyboard inputs, to the Chinese Cangjie part. Throws exception if invalid input is supplied.","title":"Unicode.Unihan.Cangjie.cangjie!/1","ref":"Unicode.Unihan.Cangjie.html#cangjie!/1"},{"type":"function","doc":"iex> Unicode.Unihan.Cangjie.cangjie!(\"U\")\n    \"山\"\n\n    iex> Unicode.Unihan.Cangjie.cangjie!([\"U\", \"J\"])\n    [\"山\", \"十\"]","title":"Example - Unicode.Unihan.Cangjie.cangjie!/1","ref":"Unicode.Unihan.Cangjie.html#cangjie!/1-example"},{"type":"function","doc":"","title":"Unicode.Unihan.Cangjie.cangjies/0","ref":"Unicode.Unihan.Cangjie.html#cangjies/0"},{"type":"module","doc":"`Unicode.Unihan.Cantonese` acts on pronunciations as a simple string\n(e.g., \"faan1\", \"gwai3\"), and provides functions to decompose these\ninto standard structs as well as checking their validity.","title":"Unicode.Unihan.Cantonese","ref":"Unicode.Unihan.Cantonese.html"},{"type":"function","doc":"Returns true if the jyutping is validly constructed.  This does not state\nanything about their usage in the language.","title":"Unicode.Unihan.Cantonese.is_valid?/1","ref":"Unicode.Unihan.Cantonese.html#is_valid?/1"},{"type":"function","doc":"iex> Unicode.Unihan.Cantonese.is_valid?(\"faan1\")\n    true\n\n    iex> Unicode.Unihan.Cantonese.is_valid?(\"m4\")\n    true\n\n    iex> Unicode.Unihan.Cantonese.is_valid?(\"lan1\")\n    true\n\n    iex> Unicode.Unihan.Cantonese.is_valid?(\"faaaan1\")\n    false\n\n    iex> Unicode.Unihan.Cantonese.is_valid?(\"faan7\")\n    false\n\n    iex> Unicode.Unihan.Cantonese.is_valid?(\"fn1\")\n    false","title":"Examples - Unicode.Unihan.Cantonese.is_valid?/1","ref":"Unicode.Unihan.Cantonese.html#is_valid?/1-examples"},{"type":"function","doc":"","title":"Unicode.Unihan.Cantonese.jyutping_index/0","ref":"Unicode.Unihan.Cantonese.html#jyutping_index/0"},{"type":"function","doc":"Returns a :ok tuple with a struct of the string containing the\njyutping split into a map with onset, nucleus, coda, tone, final,\nand jyutping as keys.\n\nThe collection of functions is generated at compile time, with one\nfor each row representing a possible pronunciation.  If the input\ndoes not match any of the exhaustive enumerations, it is invalid,\nand an error tuple is returned.","title":"Unicode.Unihan.Cantonese.to_jyutping/1","ref":"Unicode.Unihan.Cantonese.html#to_jyutping/1"},{"type":"function","doc":"iex> Unicode.Unihan.Cantonese.to_jyutping!(\"haan1\")\n    %{onset: \"h\", nucleus: \"aa\", coda: \"n\", tone: \"1\", final: \"aan\", jyutping: \"haan1\"}\n\n    iex> Unicode.Unihan.Cantonese.to_jyutping!(\"ngaang6\")\n    %{onset: \"ng\", nucleus: \"aa\", coda: \"ng\", tone: \"6\", final: \"aang\", jyutping: \"ngaang6\"}\n\n    iex> Unicode.Unihan.Cantonese.to_jyutping!(\"m4\")\n    %{onset: \"\", nucleus: \"m\", coda: \"\", tone: \"4\", final: \"m\", jyutping: \"m4\"}\n\n    iex> Unicode.Unihan.Cantonese.to_jyutping(\"xxx\")\n    {:error, \"Invalid jyutping. Found \\\"xxx\\\"\"}\n\n    iex> Unicode.Unihan.Cantonese.to_jyutping(999)\n    {:error, \"to_jyutping/1 requires a string as input\"}","title":"Examples - Unicode.Unihan.Cantonese.to_jyutping/1","ref":"Unicode.Unihan.Cantonese.html#to_jyutping/1-examples"},{"type":"function","doc":"","title":"Unicode.Unihan.Cantonese.to_jyutping!/1","ref":"Unicode.Unihan.Cantonese.html#to_jyutping!/1"},{"type":"module","doc":"`Unicode.Unihan.Radical` encapsulates the mapping from CJK radical numbers\nto characters.","title":"Unicode.Unihan.Radical","ref":"Unicode.Unihan.Radical.html"},{"type":"function","doc":"Filter the Unicode CJK radical database returning selected\ncodepoints.","title":"Unicode.Unihan.Radical.filter/1","ref":"Unicode.Unihan.Radical.html#filter/1"},{"type":"function","doc":"* `fun` is a `1-arity` function that is passed\n  the attribute map for a given codepoint. if the\n  function returns a `truthy` value then the codepoint\n  is included in the returned data. If the return\n  value is `falsy` then the codepoint is omitted\n  from the returned list.","title":"Arguments - Unicode.Unihan.Radical.filter/1","ref":"Unicode.Unihan.Radical.html#filter/1-arguments"},{"type":"function","doc":"* a map of the filtered codepoints mapped to their\n  attributes.","title":"Returns - Unicode.Unihan.Radical.filter/1","ref":"Unicode.Unihan.Radical.html#filter/1-returns"},{"type":"function","doc":"iex> Unicode.Unihan.Radical.filter(&(&1[:Hant][:radical_number] < 5))\n    ...> |> Enum.count()\n    4","title":"Example - Unicode.Unihan.Radical.filter/1","ref":"Unicode.Unihan.Radical.html#filter/1-example"},{"type":"function","doc":"Returns grapheme associated with the radical,\nas specified in the [CJK Radicals](https://www.unicode.org/reports/tr41/tr41-30.html#CJKRadicals) file.","title":"Unicode.Unihan.Radical.radical/2","ref":"Unicode.Unihan.Radical.html#radical/2"},{"type":"function","doc":"* `index` is the Unicode radical number (1..214), reported from various\n  radical stroke properties such as `kRSUnicode`.\n\n* an optional argument, which can be one of:\n  * `:unified_ideograph` (default) shows the grapheme in the (normal) CJK\n     unified ideograph Unicode block (hexadecimal 4000--6000)\n  * `:radical_character` shows the grapheme in the special, contiguous\n     KangXi Radical block (2F00--2FD5)\n  * `:all` returns the full map for the radical","title":"Arguments - Unicode.Unihan.Radical.radical/2","ref":"Unicode.Unihan.Radical.html#radical/2-arguments"},{"type":"function","doc":"iex> Unicode.Unihan.Radical.radical(187)\n    \"馬\"\n\n    iex> Unicode.Unihan.Radical.radical(187, script: :Hans)\n    \"马\"\n\n    iex> Unicode.Unihan.Radical.radical(187, script: :Hant, glyph: :radical_character)\n    \"⾺\"\n\n    iex> Unicode.Unihan.Radical.radical(213, script: :Hanj)\n    \"亀\"\n\n    iex> Unicode.Unihan.Radical.radical(187) == Unicode.Unihan.Radical.radical(187, script: :Hant, glyph: :radical_character)\n    false\n\n    iex> Unicode.Unihan.Radical.radical(187, :all)\n    %{\n      Hans: %{\n        radical_character: 12002,\n        radical_number: 187,\n        unified_ideograph: 39532\n      },\n      Hant: %{\n        radical_character: 12218,\n        radical_number: 187,\n        unified_ideograph: 39340\n      }\n    }\n\n    iex> Unicode.Unihan.Radical.radical(182, :all)\n    %{\n      Hans: %{\n        radical_character: 11995,\n        radical_number: 182,\n        unified_ideograph: 39118\n      },\n      Hant: %{\n        radical_character: 12213,\n        radical_number: 182,\n        unified_ideograph: 39080\n      },\n      Hanj: %{\n        radical_character: nil,\n        radical_number: 182,\n        unified_ideograph: 205508\n      }\n    }\n\n    iex> Unicode.Unihan.Radical.radical(999)\n    {:error, \"Invalid radical number. Valid numbers are an integer in the range 1..214\"}","title":"Examples - Unicode.Unihan.Radical.radical/2","ref":"Unicode.Unihan.Radical.html#radical/2-examples"},{"type":"function","doc":"","title":"Unicode.Unihan.Radical.radicals/0","ref":"Unicode.Unihan.Radical.html#radicals/0"},{"type":"function","doc":"Filter the Unicode CJK radical database returning selected\ncodepoints that are not rejected by the provided\nfunction.","title":"Unicode.Unihan.Radical.reject/1","ref":"Unicode.Unihan.Radical.html#reject/1"},{"type":"function","doc":"* `fun` is a `1-arity` function that is passed\n  the attribute map for a given codepoint. if the\n  function returns a `falsy` value then the codepoint\n  is included in the returned data. If the return\n  value is `truthy` then the codepoint is omitted\n  from the returned list.","title":"Arguments - Unicode.Unihan.Radical.reject/1","ref":"Unicode.Unihan.Radical.html#reject/1-arguments"},{"type":"function","doc":"* a map of the codepoints that are not rejected\n  mapped to their attributes.","title":"Returns - Unicode.Unihan.Radical.reject/1","ref":"Unicode.Unihan.Radical.html#reject/1-returns"},{"type":"function","doc":"iex> Unicode.Unihan.Radical.reject(&(&1[:Hant][:radical_number] < 5))\n    ...> |> Enum.count()\n    210","title":"Example - Unicode.Unihan.Radical.reject/1","ref":"Unicode.Unihan.Radical.html#reject/1-example"},{"type":"module","doc":"Functions to parse the Unicode Unihan database\nfiles.","title":"Unicode.Unihan.Utils","ref":"Unicode.Unihan.Utils.html"},{"type":"function","doc":"Parse the jyutping_index.csv file.","title":"Unicode.Unihan.Utils.parse_cantonese/0","ref":"Unicode.Unihan.Utils.html#parse_cantonese/0"},{"type":"function","doc":"Parse one Unicode Unihan file and return\na mapping from codepoint to a map of metadata\nfor that codepoint.","title":"Unicode.Unihan.Utils.parse_file/2","ref":"Unicode.Unihan.Utils.html#parse_file/2"},{"type":"function","doc":"Parse all Unicode Unihan files and return\na mapping from codepoint to a map of metadata\nfor that codepoint.","title":"Unicode.Unihan.Utils.parse_files/0","ref":"Unicode.Unihan.Utils.html#parse_files/0"},{"type":"function","doc":"Parse the cjk_radicals.txt file.\n\nThere is one line per CJK radical number. Each line contains three\nfields, separated by a semicolon (';'). The first field is the\nCJK radical number. The second field is the CJK radical character, which may be absent. The third field is the CJK unified ideograph.\n\nA given radical may have three variants, sharing the same radical number but described in separate lines.  These variants are noted with one or two trailing apostrophes `'`:\n* one trailing apostrophe `'`: simplified radicals\n* two trailing apostrophe `''`: japanese radicals (added in 2023 version 15.1)","title":"Unicode.Unihan.Utils.parse_radicals/0","ref":"Unicode.Unihan.Utils.html#parse_radicals/0"},{"type":"function","doc":"Returns a map of the field definitions for a\nUnihan codepoint.","title":"Unicode.Unihan.Utils.unihan_properties/0","ref":"Unicode.Unihan.Utils.html#unihan_properties/0"},{"type":"function","doc":"","title":"Unicode.Unihan.Utils.unihan_properties_file/0","ref":"Unicode.Unihan.Utils.html#unihan_properties_file/0"},{"type":"extras","doc":"# Unicode Unihan\n\n[![Hex Version](https://img.shields.io/hexpm/v/unicode_unihan.svg)](https://hex.pm/packages/unicode_unihan)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/unicode_unihan/)\n[![Download/Week](https://img.shields.io/hexpm/dw/unicode_unihan.svg?)](https://hex.pm/packages/unicode_unihan)\n[![License](https://img.shields.io/hexpm/l/unicode_unihan.svg)](https://hex.pm/packages/unicode_unihan)\n[![Last Updated](https://img.shields.io/github/last-commit/elixir-unicode/unicode_unihan.svg)](https://github.com/elixir-unicode/unicode_unihan/commits/master)\n\nFunctions to return information about Unicode Unihan codepoints.","title":"Unicode Unihan","ref":"readme.html"},{"type":"extras","doc":"The package can be installed by adding `:unicode_unihan` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:unicode_unihan, \"~> 0.4\"}\n  ]\nend\n```","title":"Installation - Unicode Unihan","ref":"readme.html#installation"},{"type":"extras","doc":"Twice a year the Unicode consortium releases a new version of the Unicode database. This updated data can then be used in `unicode_unihan` by running the following mix task:\n\n```bash\nmix unicode.unihan.download\n```","title":"Updating the Unihan database - Unicode Unihan","ref":"readme.html#updating-the-unihan-database"},{"type":"extras","doc":"Lookup a character by codespoint in IEx:\n\n```elixir\niex> Unicode.Unihan.unihan(33836)\n%{\n  kTang: %{frequent: true, reading: \"miæ̀n\"},\n  kSBGY: %{position: 37, page: 397},\n  kCantonese: %{\n    final: \"aan\",\n    jyutping: \"maan6\",\n    coda: \"n\",\n    nucleus: \"aa\",\n    onset: \"m\",\n    tone: \"6\"\n  },\n  kCihaiT: %{position: 2, page: 1149, row: 4},\n  kTotalStrokes: %{Hans: 12, Hant: 12},\n  kXerox: \"242:161\",\n  kSimplifiedVariant: 19975,\n  kJapanese: [\"バン\", \"マン\", \"よろず\"],\n  kIICore: %{priority: \"A\", irg: [\"T\", \"J\", \"H\", \"K\", \"M\", \"P\"]},\n  kIRG_JSource: %{source: \"J0\", mapping: \"685F\"},\n  kCNS1992: \"1-655C\",\n  kCNS1986: \"1-655C\",\n  kIRG_VSource: %{source: \"V1\", mapping: \"6538\"},\n  kKorean: \"MAN\",\n  kCowles: 2576,\n  kHangul: %{source: \"0E\", grapheme: \"만\"},\n  kFenn: %{fenn_phonetic: 576, importance: \"C\"},\n  kNelson: 3984,\n  kRSAdobe_Japan1_6: %{\n    code: \"C\",\n    cid: 6408,\n    kangxi: 140,\n    strokes_radical: 3,\n    strokes_residue: 9\n  },\n  kCangjie: [\"T\", \"W\", \"L\", \"B\"],\n  kVietnamese: \"vạn\",\n  kFourCornerCode: %{\n    upper_left: 4,\n    upper_right: 4,\n    lower_left: 4,\n    lower_right: 2,\n    center: 7\n  },\n  kSMSZD2003Readings: \"wàn粵maan6\",\n  kKangXi: %{position: 33, virtual: false, page: 1042},\n  kIRG_KSource: %{source: \"K0\", mapping: \"583F\"},\n  kGSR: %{index: 267, letter: \"a\", prime: \"\"},\n  kMandarin: \"wàn\",\n  kCCCII: \"214F22\",\n  kXHC1983: %{position: 4, entry: 1, page: 1185, reading: \"wàn\"},\n  kJinmeiyoKanji: %{year: 2010, codepoint: 19975},\n  kFennIndex: %{position: 3, page: 593},\n  kHanyuPinyin: %{\n    location: [%{position: 8, virtual: false, page: 53247}],\n    readings: [\"wàn\"]\n  },\n  kHanYu: %{position: 8, virtual: false, page: 3247, volume: 5},\n  kHanyuPinlu: %{reading: \"wàn\", frequency: 1335},\n  kDefinition: [\"ten thousand\", \" innumerable\"],\n  kIRGDaeJaweon: %{position: 6, virtual: false, page: 1501},\n  kIRG_HSource: %{source: \"HB1\", mapping: \"B855\"},\n  kBigFive: {47189, \"\"},\n  kPrimaryNumeric: 10000,\n  kMatthews: %{index: 7030, trailing: \"\"},\n  kMorohashi: %{index: 31339, prime: \"\"},\n  codepoint: 33836,\n  kIRG_GSource: %{source: \"G1\", mapping: [\"4D72\"]},\n  kIRG_KPSource: %{source: \"KP0\", mapping: \"DAC6\"},\n  kDaeJaweon: %{position: 6, virtual: false, page: 1501},\n  kGradeLevel: 4,\n  kTaiwanTelegraph: 5502,\n  kEACC: 2182946,\n  kMojiJoho: [\"MJ022254\", ...],\n  kSemanticVariant: [...],\n  ...\n}\n```\n\nFor more details, see the [guide to Unihan and Unihan introspection](https://raw.githubusercontent.com/elixir-unicode/unicode_unihan/main/docs/unihan_walkthrough.livemd) Livebook, or:\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fraw.githubusercontent.com%2Felixir-unicode%2Funicode_unihan%2Fmain%2Fdocs%2Funihan_walkthrough.livemd)","title":"Usage - Unicode Unihan","ref":"readme.html#usage"},{"type":"extras","doc":"Copyright (c) 2023-2024 Kip Cole ([@kipcole9](https://github.com/kipcole9)) & Jon Chui ([@jkwchui](https://github.com/jkwchui))\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n> https://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.\n\nThe Unihan Database data files in this repository are governed by the terms of\nthe [Unicode, Inc. License Agreement](https://www.unicode.org/license.html).","title":"Copyright and License - Unicode Unihan","ref":"readme.html#copyright-and-license"},{"type":"extras","doc":"# License\n\nCopyright 2023 Kip Cole (@kipcole9) & Jon Chui (@jkwchui)\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n> https://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.\n\nThe Unihan Database data files in this repository are governed by the terms of\nthe [Unicode, Inc. License Agreement](https://www.unicode.org/license.html).","title":"License","ref":"license.html"},{"type":"extras","doc":"# Changelog","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"This is the changelog for Unicode Unihan v0.4.0 released on July 1st. 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_unihan/tags)","title":"Unicode Unihan v0.4.0 - Changelog","ref":"changelog.html#unicode-unihan-v0-4-0"},{"type":"extras","doc":"* Updated to [Unicode 15.1](https://www.unicode.org/versions/Unicode15.1.0/)\n\n* Property information is autogenerated from [TR38 UNICODE HAN DATABASE (UNIHAN](https://www.unicode.org/reports/tr38/#AlphabeticalListing).\n\n* Diagnostic output uses `Logger.info/2` rather than `IO.puts/1`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Unicode Unihan v0.3.0 released on June 4th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_unihan/tags)","title":"Unicode Unihan v0.3.0 - Changelog","ref":"changelog.html#unicode-unihan-v0-3-0"},{"type":"extras","doc":"* Ensure all data paths are resolved at runtime, not compile time.\n\n* Move data/ to priv/ since only priv/ is preserved in releases.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Unicode Unihan v0.2.0 released on May 31st, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_unihan/tags)","title":"Unicode Unihan v0.2.0 - Changelog","ref":"changelog.html#unicode-unihan-v0-2-0"},{"type":"extras","doc":"* Improves compilation time by orders of magnitude by switching to use `:persistent_term` for storing the Unihan database.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Unicode Unihan v0.1.0 released on May 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_unihan/tags)","title":"Unicode Unihan v0.1.0 - Changelog","ref":"changelog.html#unicode-unihan-v0-1-0"},{"type":"extras","doc":"* Initial Release.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"# Unihan Properties\n\nThe Unihan database provides detailed descriptions for each CJK ideograph.  These descriptions (*properties*) are plain text, and can themselves be grouped into categories.\n\nProperties in Unihan, for historical reasons, have names that begins with `k`.  Examples include `kGradeLevel`, `kKangXi`, and `kStrange`.  The string in each field can contain a single entry, or a list of entries separated by a delimiter; each entry is encoded in a special format according to the needs of the field.  For example, `kKangXi` describes where to find the ideograph in the 《康熙字典》Kangxi Dictionary, and a typical entry may be \"1187.061\".  The user is expected to consult the Unihan specifications to interpret this as page 1187, position 6, and virtual (the trailing 1 indicates that the ideograph is *not* actually in the dictionary).\n\nThe `Unicode.Unihan` module simplifies access by parsing these into sensible structures.  Each character is represented as a map, with atom keys (e.g., `:kKangXi`) used to access properties.  Where multiple entries exists inside a property, they are split into a list; each entry is parsed into a map.  The example entry above would be structured to:\n\n```elixir\n%{\n    page: 1187,\n    position: 6,\n    virtual: true\n}\n```\n\nThe contents of entries are cast into appropriate types (for example, integer for `page`).  This facilitates access using the `filter/1` and `reject/1` functions: you can now isolate all characters in KangXi Dictionary between pages 1100--1200, or all the virtual characters; since `filter/1` and `reject/1` accept arbitrary functions, you can even combine properties and compose a query for \"virtual characters in KangXi that are *also* grade-level 3 or below\".\n\nIn the accompanying pages, we describe in some detail what the properties are and how entries were parsed.  These are grouped thematically as follows:\n\n* [Dictionary Indices](properties/dictionary_indices.md): kCheungBauerIndex, kCihaiT, kCowles, kDaeJaweon, kFennIndex, kGSR, kHanYu, kIRGDaeJaweon, kIRGDaiKanwaZiten, kIRGHanyuDaZidian, kIRGKangXi, kKangXi, kKarlgren, kLau, kMatthews, kMeyerWempe, kMorohashi, kNelson, kSBGY\n\n* [Dictionary-like data](properties/dictionary_like_data.md): kAlternateTotalStrokes, kCangjie, kCheungBauer, kFenn, kFourCornerCode, kFrequency, kGradeLevel, kHDZRadBreak, kHKGlyph, kPhonetic, kStrange, kUnihanCore2020\n\n* [IRG sources](properties/irg_sources.md): kCompatibilityVariant, kIICore, kIRG_GSource, kIRG_HSource, kIRG_JSource, kIRG_KPSource, kIRG_KSource, kIRG_MSource, kIRG_SSource, kIRG_TSource, kIRG_UKSource, kIRG_USource, kIRG_VSource, kRSUnicode, kTotalStrokes\n\n* [Numeric values](properties/numeric_values.md): kAccountingNumeric, kOtherNumeric, kPrimaryNumeric\n\n* [Other mappings](properties/other_mappings.md): kBigFive, kCCCII, kCNS1986, kCNS1992, kEACC, kGB0, kGB1, kGB3, kGB5, kGB7, kGB8, kHKSCS, kIBMJapan, kJa, kJinmeiyoKanji, kJis0, kJis1, kJIS0213, kJoyoKanji, kKoreanEducationHanja, kKoreanName, kKPS0, kKPS1, kKSC0, kKSC1, kMainlandTelegraph, kPseudoGB1, kTaiwanTelegraph, kTGH, kXerox\n\n* [Radical Stroke Counts](properties/radical_stroke_counts.md): kRSAdobe_Japan1_6, kRSKangXi\n\n* [Readings](properties/readings.md): kCantonese, kDefinition, kHangul, kHanyuPinlu, kHanyuPinyin, kJapaneseKun, kJapaneseOn, kKorean, kMandarin, kTang, kTGHZ2013, kVietnamese, kXHC1983\n\n* [Variants](properties/variants.md): kSemanticVariant, kSimplifiedVariant, kSpecializedSemanticVariant, kSpoofingVariant, kTraditionalVariant, kZVariant","title":"Unihan Properties","ref":"properties.html"},{"type":"extras","doc":"# Dictionary Indices","title":"Dictionary Indices","ref":"dictionary_indices.html"},{"type":"extras","doc":"","title":"kCheungBauerIndex - Dictionary Indices","ref":"dictionary_indices.html#kcheungbauerindex"},{"type":"extras","doc":"> The position of the character in Cheung Kwan-hin and Robert S. Bauer, The Representation of Cantonese with Chinese Characters, Journal of Chinese Linguistics, Monograph Series Number 18, 2002. The format is a three-digit page number followed by a two-digit position number, separated by a period.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"```elixir\n%{\n    page: 381,\n    position: 1\n}\n```\n\nBoth `:page` and `:position` are integers.\n\nWhere multiple entries were provided in Cheung & Bauer, the entries are provided as a list:\n\n```elixir\n   [\n     %{page: 366, position: 5},\n     %{page: 366, position: 6},\n     %{page: 366, position: 7},\n     %{page: 366, position: 8}\n   ]\n```","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"Cheung Bauer includes 967 characters specifically used in representing Cantonese.  Examples include 㖭,㗎, and 𬧊.  Note that many of these characters reside in the Extension planes and may not be contained in standard fonts.","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kCihaiT - Dictionary Indices","ref":"dictionary_indices.html#kcihait"},{"type":"extras","doc":"> The position of this character in the Cihai (辭海) dictionary, single volume edition, published in Hong Kong by the Zhonghua Bookstore, 1983 (reprint of the 1947 edition), ISBN 962-231-005-2.  The position is indicated by a decimal number. The digits to the left of the decimal are the page number. The first digit after the decimal is the row on the page, and the remaining two digits after the decimal are the position on the row.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"```elixir\n%{page: 1552, position: 7, row: 4}\n```\n\nAll three values are integers.","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"13,886 characters contains an `:kCihaiT` field.  These are exclusively Traditional characters.","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kCowles - Dictionary Indices","ref":"dictionary_indices.html#kcowles"},{"type":"extras","doc":">  \tThe index or indices of this character in Roy T. Cowles, A Pocket Dictionary of Cantonese, Hong Kong: University Press, 1999.  The Cowles indices are numerical, usually integers but occasionally fractional where a character was added after the original indices were determined. \n\n> Cowles is missing indices 1222 and 4949, and four characters in Cowles are part of Unicode’s “Hangzhou” numeral set: 2964 (U+3025), 3197 (U+3028), 3574 (U+3023), and 4720 (U+3027).","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"`:kCowles` returns *exclusively* an integer.","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"4863 Traditional characters.  Note that trailing decimals are dropped in this parsing implementation.","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kDaeJaweon - Dictionary Indices","ref":"dictionary_indices.html#kdaejaweon"},{"type":"extras","doc":"> The position of this character in the Dae Jaweon (Korean) dictionary used in the four-dictionary sorting algorithm. The position is in the form “page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary and assigned a “virtual” position in the dictionary.\n\n> Thus, “1187.060” indicates the sixth character on page 1187. A character not in this dictionary but assigned a position between the 6th and 7th characters on page 1187 for sorting purposes would have the code “1187.061”\n\n> The edition used is the first edition, published in Seoul by Samseong Publishing Co., Ltd., 1988.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kFennIndex - Dictionary Indices","ref":"dictionary_indices.html#kfennindex"},{"type":"extras","doc":">  \tThe position of this character in The Five Thousand Dictionary by Courtenay H. Fenn, Cambridge, Mass.: Harvard University Press, 1979. The position is indicated by a three-digit page number followed by a period and a two-digit position on the page.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kGSR - Dictionary Indices","ref":"dictionary_indices.html#kgsr"},{"type":"extras","doc":"> The position of this character in Bernhard Karlgren’s Grammata Serica Recensa (1957).\n\n> This dataset contains a total of 7,405 records. References are given in the form DDDDa('), where “DDDD” is a set number in the range [0001..1260] zero-padded to 4-digits, “a” is a letter in the range [a..z] (excluding “w”), optionally followed by apostrophe ('). The data from which this mapping table is extracted contains a total of 10,023 references. References to inscriptional forms have been omitted.\n\nThis entry is abridged.  See [Annex #38](https://www.unicode.org/reports/tr38/#kGSR) for a more complete description.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kHanYu - Dictionary Indices","ref":"dictionary_indices.html#khanyu"},{"type":"extras","doc":"> The position of this character in the Hànyǔ Dà Zìdiǎn (HDZ) Chinese character dictionary (bibliographic information below).\n\n> The character references are given in the form “ABCDE.XYZ”, in which: “A” is the volume number [1..8]; “BCDE” is the zero-padded page number [0001..4809]; “XY” is the zero-padded number of the character on the page [01..32]; “Z” is “0” for a character actually in the dictionary, and greater than 0 for a character assigned a “virtual” position in the dictionary. For example, 53024.060 indicates an actual HDZ character, the 6th character on Page 3,024 of Volume 5 (i.e. 籉 [U+7C49]). Note that the Volume 8 “BCDE” references are in the range [0008..0044] inclusive, referring to the pagination of the “Appendix of Addendum” at the end of that volume (beginning after p. 5746).\n\n> The first character assigned a given virtual position has an index ending in 1; the second assigned the same virtual position has an index ending in 2; and so on.\n\nThis entry is abridged.  See [Annex #38](https://www.unicode.org/reports/tr38/#kHanYu) for a more complete description.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kIRGDaeJaweon - Dictionary Indices","ref":"dictionary_indices.html#kirgdaejaweon"},{"type":"extras","doc":"> The position of this character in the Dae Jaweon (Korean) dictionary used in the four-dictionary sorting algorithm. The position is in the form “page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary and assigned a “virtual” position in the dictionary.\n\n> Thus, “1187.060” indicates the sixth character on page 1187. A character not in this dictionary but assigned a position between the 6th and 7th characters on page 1187 for sorting purposes would have the code “1187.061”\n\n> This field represents the official position of the character within the Dae Jaweon dictionary as used by the IRG in the four-dictionary sorting algorithm.\n\n> The edition used is the first edition, published in Seoul by Samseong Publishing Co., Ltd., 1988.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kIRGDaiKanwaZiten - Dictionary Indices","ref":"dictionary_indices.html#kirgdaikanwaziten"},{"type":"extras","doc":">  \tThe index of this character in the Dai Kanwa Ziten, aka Morohashi dictionary (Japanese) used in the four-dictionary sorting algorithm. This field represents the official position of the character within the Dai Kanwa Ziten as used by the IRG in the four-dictionary sorting algorithm. The edition used is the revised edition, published in Tokyo by Taishuukan Shoten, 1986.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kIRGHanyuDaZidian - Dictionary Indices","ref":"dictionary_indices.html#kirghanyudazidian"},{"type":"extras","doc":"> The position of this character in the Hànyǔ Dà Zìdiǎn (PRC) dictionary used in the four-dictionary sorting algorithm. The position is in the form “volume page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary and assigned a “virtual” position in the dictionary.\n\n> Thus, “32264.080” indicates the eighth character on page 2264 in volume 3. A character not in this dictionary but assigned a position between the 8th and 9th characters on this page for sorting purposes would have the code “32264.081”\n\n> This field represents the official position of the character within the Hànyǔ Dà Zìdiǎn dictionary as used by the IRG in the four-dictionary sorting algorithm.\n\n> The edition of the Hanyu Da Zidian used is the first edition, published in Chengdu by Sichuan Cishu Publishing, 1986.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kIRGKangXi - Dictionary Indices","ref":"dictionary_indices.html#kirgkangxi"},{"type":"extras","doc":"> The official IRG position of this character in the 《康熙字典》 Kangxi Dictionary used in the four-dictionary sorting algorithm. The position is in the form “page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary but assigned a “virtual” position in the dictionary.\n\n> Thus, “1187.060” indicates the sixth character on page 1187. A character not in this dictionary but assigned a position between the 6th and 7th characters on page 1187 for sorting purposes would have the code “1187.061”.\n\n> The edition of the Kangxi Dictionary used is the 7th edition published by Zhonghua Bookstore in Beijing, 1989.\n\n> The values in the `kIRGKangXi` field are a strict subset of those in the `kKangXi` field.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kKangXi - Dictionary Indices","ref":"dictionary_indices.html#kkangxi"},{"type":"extras","doc":">  \tThe position of this character in the《康熙字典》Kangxi Dictionary used in the four-dictionary sorting algorithm. The position is in the form “page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary but assigned a “virtual” position in the dictionary.\n\n> Thus, “1187.060” indicates the sixth character on page 1187. A character not in this dictionary but assigned a position between the 6th and 7th characters on page 1187 for sorting purposes would have the code “1187.061”.\n\n> The edition of the Kangxi Dictionary used is the 7th edition published by Zhonghua Bookstore in Beijing, 1989.\n\n> The values in the `kKangXi` field are a strict superset of those in the `kIRGKangXi` field.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kKarlgren - Dictionary Indices","ref":"dictionary_indices.html#kkarlgren"},{"type":"extras","doc":"> The index of this character in Analytic Dictionary of Chinese and Sino-Japanese by Bernhard Karlgren, New York: Dover Publications, Inc., 1974.\n\n> If the index is followed by an asterisk (*), then the index is an interpolated one, indicating where the character would be found if it were to have been included in the dictionary. Note that while the index itself is usually an integer, there are some cases where it is an integer followed by an “A”.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kLau - Dictionary Indices","ref":"dictionary_indices.html#klau"},{"type":"extras","doc":"> The index of this character in A Practical Cantonese-English Dictionary by Sidney Lau, Hong Kong: The Government Printer, 1977. The index consists of an integer. Missing indices indicate characters to be found in [UAX45].","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kMatthews - Dictionary Indices","ref":"dictionary_indices.html#kmatthews"},{"type":"extras","doc":"> The index of this character in Chinese-English Dictionary by Robert H. Mathews, Cambridge: Harvard University Press, 1975.\n\n> Note that the field name is kMatthews instead of kMathews to maintain compatibility with earlier versions of this file, where it was inadvertently misspelled.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kMeyerWempe - Dictionary Indices","ref":"dictionary_indices.html#kmeyerwempe"},{"type":"extras","doc":"> The index of this character in the Student’s Cantonese-English Dictionary by Bernard F. Meyer and Theodore F. Wempe (3rd edition, 1947). The index is an integer, optionally followed by a lowercase Latin letter if the listing is in a subsidiary entry and not a main one. In some cases, where the character is found in the radical-stroke index, but not in the main body of the dictionary, the integer is followed by an asterisk: for example, U+50E5 僥, which is listed as 736* as well as 1185a.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kMorohashi - Dictionary Indices","ref":"dictionary_indices.html#kmorohashi"},{"type":"extras","doc":"> The index of this character in the Dai Kanwa Ziten, aka Morohashi dictionary (Japanese) used in the four-dictionary sorting algorithm. The edition used is the revised edition, published in Tokyo by Taishūkan Shoten, 1986.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kNelson - Dictionary Indices","ref":"dictionary_indices.html#knelson"},{"type":"extras","doc":"> The index of this character in The Modern Reader’s Japanese-English Character Dictionary by Andrew Nathaniel Nelson, Rutland, Vermont: Charles E. Tuttle Company, 1974.","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"","title":"kSBGY - Dictionary Indices","ref":"dictionary_indices.html#ksbgy"},{"type":"extras","doc":"> The position of this character in the Song Ben Guang Yun (SBGY) Medieval Chinese character dictionary (bibliographic and general information below).\n\n> The 25334 character references are given in the form “ABC.XY”, in which: “ABC” is the zero-padded page number [004..546]; “XY” is the zero-padded number of the character on the page [01..73]. For example, 364.38 indicates the 38th character on Page 364 (i.e. 澍). Where a given Unicode Scalar Value (USV) has more than one reference, these are space-delimited.\n\nThis is an abridged entry.  For details see [Annex #38](https://www.unicode.org/reports/tr38/#kSBGY).","title":"Description - Dictionary Indices","ref":"dictionary_indices.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary Indices","ref":"dictionary_indices.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary Indices","ref":"dictionary_indices.html#notes"},{"type":"extras","doc":"# Dictionary-like data","title":"Dictionary-like data","ref":"dictionary_like_data.html"},{"type":"extras","doc":"","title":"kAlternateTotalStrokes - Dictionary-like data","ref":"dictionary_like_data.html#kalternatetotalstrokes"},{"type":"extras","doc":"> The total number of strokes in the character (including the radical). Each value consists either of a decimal value followed by an IRG source specifier as defined in Section 3.10, or of the special value “-”.\n\n> The IRG source specifier indicates the IRG sources for which a particular value is preferred. The source identifiers “G” and “T” are not used in this field, as these IRG sources are fully covered by the kTotalStrokes field.\n\n> The stroke count value is the one for the glyph as shown in the code charts.\n\n> Multiple stroke counts are listed in increasing numeric order. Stroke counts may not be repeated.\n\nThis is an abridged entry.  For examples and details, see [its entry](https://www.unicode.org/reports/tr38/#kAlternateTotalStrokes) in Annex #38.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kCangjie - Dictionary-like data","ref":"dictionary_like_data.html#kcangjie"},{"type":"extras","doc":"> The cangjie input code for the character. This incorporates data from the file cangjie-table.b5 by Christian Wittern.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kCheungBauer - Dictionary-like data","ref":"dictionary_like_data.html#kcheungbauer"},{"type":"extras","doc":"> Data regarding the character in Cheung Kwan-hin and Robert S. Bauer, The Representation of Cantonese with Chinese Characters, Journal of Chinese Linguistics, Monograph Series Number 18, 2002. Each data value consists of three pieces, separated by semicolons: (1) the character’s radical-stroke index as a three-digit radical, slash, two-digit stroke count; (2) the character’s cangjie input code (if any); and (3) a comma-separated list of Cantonese readings using the jyutping romanization in alphabetical order.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kFenn - Dictionary-like data","ref":"dictionary_like_data.html#kfenn"},{"type":"extras","doc":"> Data on the character from The Five Thousand Dictionary by Courtenay H. Fenn, Cambridge, Mass.: Harvard University Press, 1979.\n\n> The data here consists of a decimal number followed by a letter A through K, the letter P, or an asterisk. The decimal number gives the Soothill number for the character’s phonetic, and the letter is a rough frequency indication, with A indicating the 500 most common ideographs, B the next five hundred, and so on.\n\n> P is used by Fenn to indicate a rare character included in the dictionary only because it is the phonetic element in other characters.\n\n> An asterisk is used instead of a letter in the final position to indicate a character which belongs to one of Soothill’s phonetic groups but is not found in Fenn’s dictionary.\n\n> Characters which have a frequency letter but no Soothill phonetic group are assigned group 0.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kFourCornerCode - Dictionary-like data","ref":"dictionary_like_data.html#kfourcornercode"},{"type":"extras","doc":"> The four-corner code(s) for the character. This data is derived from data provided in the public domain by Hartmut Bohn, Urs App, and Christian Wittern.\n\n> The four-corner system assigns each character a four-digit code from 0 through 9. The digit is derived from the “shape” of the four corners of the character (upper-left, upper-right, lower-left, lower-right). An optional fifth digit can be used to further distinguish characters; the fifth digit is derived from the shape in the character’s center or region immediately to the left of the fourth corner.\n\n> The four-corner system is now used only rarely. Full descriptions are available online, for example, at http://en.wikipedia.org/wiki/Four_corner_input.\n\n> Values in this field consist of four decimal digits, optionally followed by a period and fifth digit for a five-digit form.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kFrequency - Dictionary-like data","ref":"dictionary_like_data.html#kfrequency"},{"type":"extras","doc":"> A rough frequency measurement for the character based on analysis of traditional Chinese USENET postings; characters with a kFrequency of 1 are the most common, those with a kFrequency of 2 are less common, and so on, through a kFrequency of 5.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kGradeLevel - Dictionary-like data","ref":"dictionary_like_data.html#kgradelevel"},{"type":"extras","doc":"> The primary grade in the Hong Kong school system by which a student is expected to know the character; this data is derived from 朗文初級中文詞典, Hong Kong: Longman, 2001.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kHDZRadBreak - Dictionary-like data","ref":"dictionary_like_data.html#khdzradbreak"},{"type":"extras","doc":"> Indicates that 《漢語大字典》 Hanyu Da Zidian has a radical break beginning at this character’s position. The field consists of the radical (with its Unicode code point), a colon, and then the Hanyu Da Zidian position as in the kHanyu field.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kHKGlyph - Dictionary-like data","ref":"dictionary_like_data.html#khkglyph"},{"type":"extras","doc":"> The index of the character in 常用字字形表 (二零零零年修訂本),香港: 香港教育學院, 2000, ISBN 962-949-040-4. This publication gives the “proper” shapes for 4759 characters as used in the Hong Kong school system. The index is an integer, zero-padded to four digits.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kPhonetic - Dictionary-like data","ref":"dictionary_like_data.html#kphonetic"},{"type":"extras","doc":"> The phonetic class for the character, as adopted from Ten Thousand Characters: An Analytic Dictionary, by G. Hugh Casey, S.J. Hong Kong: Kelly and Walsh, 1980.\n\n> Characters in the same phonetic class have a common phonetic element, such as 耕 (U+8015) and 阱 (U+9631), both assigned to the phonetic class 103. Most classes have a prototype character, which serves as the common phonetic element for the remaining members of the class. For example, 乍 (U+4E4D) is the prototype for characters of class 10.\n\n> Some classes are associated with one to four subsidiary classes, indicated by the letters A through D.\n\n> Some characters are assigned multiple classes. This can happen, for example, when a character belongs to one class but is also the prototype for a different class. For example, 國 (U+570B) is the prototype for class 748, but is also a member of class 1416, which has 或 (U+6216) as its prototype. Its kPhonetic value is therefore \"748 1416.\"\n\n> Multiple values are always in ascending numerical order.\n\n> An asterisk is appended when a character has the given phonetic class but is not explicitly included in the character list for that class. For example, 蝓 (U+8753) belongs to the class 1611 but is not explicitly listed in that class. Its kPhonetic value is therefore \"1611*\".\n\n> Casey includes a radical-stroke index mapping characters to their phonetic class. In some cases, this mapping is in error; when this happens, a lowercase \"x\" is appended to the index. For example, 萑 (U+8411) is assigned to the classes 216 and 285, but the assignment to class 216 is clearly in error. Its kPhonetic value is therefore \"216x 285\".","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kStrange - Dictionary-like data","ref":"dictionary_like_data.html#kstrange"},{"type":"extras","doc":"> This property identifies CJK Unified Ideographs that are considered \"strange\" in one or more ways per the following 12 categories:\n\n> Category A = [A]symmetric (exhibits a structure that is asymmetric)\n> Category B = [B]opomofo (visually resembles a bopomofo character)\n> Category C = [C]ursive (is cursive or includes one or more cursive components that do not adhere to Han ideograph stroke conventions)\n> Category F = [F]ully-reflective (is fully-reflective or includes components that are fully-reflective, meaning that the mirrored and unmirrored components are arranged side-by-side or stacked top-and-bottom)\n> Category H = [H]angul Component (includes a hangul component)\n> Category I = [I]ncomplete (appears to be an incomplete version of an existing or possible ideograph, meaning that one or more components appear to be incomplete, without regard to semantics)\n> Category K = [K]atakana Component (includes one or more components that visually resemble a katakana syllable)\n> Category M = [M]irrored (is either mirrored or includes one or more components that are mirrored)\n> Category O = [O]dd Component (includes one or more components that are symbol-like or are otherwise considered odd)\n> Category R = [R]otated (is either rotated or includes one or more components that are rotated)\n> Category S = [S]troke-heavy (has 40 or more strokes)\n> Category U = [U]nusual Arrangement/Structure (has an unusual structure or component arrangement)\n\n> This property is fully documented in [UTN43](https://www.unicode.org/notes/tn43/), Unihan Database Property “kStrange”.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"","title":"kUnihanCore2020 - Dictionary-like data","ref":"dictionary_like_data.html#kunihancore2020"},{"type":"extras","doc":"> Used for characters which are in the UnihanCore2020 set, the minimal set of required ideographs for East Asia. A character is in the UnihanCore2020 set if and only if it has a value for the kUnihanCore2020 property.","title":"Description - Dictionary-like data","ref":"dictionary_like_data.html#description"},{"type":"extras","doc":"","title":"Shape of return - Dictionary-like data","ref":"dictionary_like_data.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Dictionary-like data","ref":"dictionary_like_data.html#notes"},{"type":"extras","doc":"# IRG sources","title":"IRG sources","ref":"irg_sources.html"},{"type":"extras","doc":"","title":"kCompatibilityVariant - IRG sources","ref":"irg_sources.html#kcompatibilityvariant"},{"type":"extras","doc":"> The canonical Decomposition_Mapping value for the ideograph, derived from UnicodeData.txt. This field is derived by taking the non-null Decomposition_Mapping values from Field 5 of UnicodeData.txt, for characters contained within the CJK Compatibility Ideographs block and the CJK Compatibility Ideographs Supplement block.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIICore - IRG sources","ref":"irg_sources.html#kiicore"},{"type":"extras","doc":"> Used for characters which are in IICore, the IRG-produced minimal set of required ideographs for East Asian use. A character is in IICore if and only if it has a value for the kIICore field.\n\n> Each value consists of a letter (A, B, or C), indicating priority value, followed by an IRG source specifier as defined in Section 3.10 above.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_GSource - IRG sources","ref":"irg_sources.html#kirg_gsource"},{"type":"extras","doc":"> The IRG “G” source mapping for this character in hexadecimal or decimal. The IRG G source consists of data from the following national standards, publications, and lists from the People’s Republic of China and Singapore. The versions of the standards used are those provided by the PRC to the IRG and may not always reflect published versions of the standards generally available.\n\nThis is an abridged entry.  For what the G source standards are referring to, see the `kIRG_GSource` [entry](https://www.unicode.org/reports/tr38/#kIRG_GSource) in Annex #38.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_HSource - IRG sources","ref":"irg_sources.html#kirg_hsource"},{"type":"extras","doc":"> The IRG “H” source mapping for this character in hexadecimal. The IRG “H” source consists of data from the following sources:\n\n> H Hong Kong Supplementary Character Set – 2008\n> HB0 Big-5: Computer Chinese Glyph and Character Code Mapping Table, Technical Report C-26, 電腦用中文字型與字碼對照表, 技術通報C-26, 1984, Symbols\n> HB1 Big-5, Level 1\n> HB2 Big-5, Level 2\n> HD Hong Kong Supplementary Character Set – 2016\n> HU The source reference for this character has been moved; the value is its code point.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_JSource - IRG sources","ref":"irg_sources.html#kirg_jsource"},{"type":"extras","doc":"> The IRG “J” source mapping for this character in hexadecimal or decimal. The IRG “J” source consists of data from the following national standards and lists from Japan.\n\nThis is an abridged entry.  See the `kIRG_JSource` [entry](https://www.unicode.org/reports/tr38/#kIRG_JSource) in Annex #38 for detailed list of what national standards are referred to by the acronyms.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_KPSource - IRG sources","ref":"irg_sources.html#kirg_kpsource"},{"type":"extras","doc":"> The IRG “KP” source mapping for this character in hexadecimal. The IRG “KP” source consists of data from the following national standards and lists from the Democratic People’s Republic of Korea (North Korea).\n\n> KP0 KPS 9566-97\n> KP1 KPS 10721-2000\n> KPU The source reference for this character has been moved; the value is its code point.\n\n> It is currently not possible to communicate with standards bodies within the DPRK. There may, therefore, be erroneous data in the values for this field.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_KSource - IRG sources","ref":"irg_sources.html#kirg_ksource"},{"type":"extras","doc":"> The IRG “K” source mapping for this character in hexadecimal or decimal. The IRG “K” source consists of data from the following national standards and lists from the Republic of Korea (South Korea).\n\nThis is an abridged entry.  See the `kIRG_KSource` [entry](https://www.unicode.org/reports/tr38/#kIRG_KSource) in Annex #38 for detailed list of what national standards are referred to by the acronyms.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_MSource - IRG sources","ref":"irg_sources.html#kirg_msource"},{"type":"extras","doc":"> The IRG “M” source mapping for this character in decimal. The IRG “M” source corresponds to MSCS (Macao Supplementary Character Set).\n\n> MA HKSCS-2008 code point in hexadecimal\n> MB Big Five code point in hexadecimal\n> MC MSCS reference\n> MD MSCS horizontal extensions","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_SSource - IRG sources","ref":"irg_sources.html#kirg_ssource"},{"type":"extras","doc":"> The IRG “S” source mapping for this character that corresponds to Taishō Shinshū Daizōkyō (大正新脩大藏經), 1924–1934, which is accessible in the SAT Daizōkyō Text Database. The source references consist of “SAT” followed by a hyphen and five decimal digits, zero padded.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_TSource - IRG sources","ref":"irg_sources.html#kirg_tsource"},{"type":"extras","doc":"> The IRG “T” source mapping for this character in hexadecimal. The IRG “T” source consists of data from the following standards and lists. “TCA” stands for “Taipei Computer Association,” and “CNS” stands for “Chinese National Standard.”\n\nThis is an abridged entry.  See the `kIRG_TSource` [entry](https://www.unicode.org/reports/tr38/#kIRG_TSource) in Annex #38 for detailed list of what national standards are referred to by the acronyms.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_UKSource - IRG sources","ref":"irg_sources.html#kirg_uksource"},{"type":"extras","doc":"> The IRG “UK” source mapping for this character in decimal. The source references consist of “UK” followed by a hyphen and five decimal digits, zero padded. The IRG “UK” source currently consists of data from the documents IRG N2107R2 and IRG N2232R that are available in the [UK-source Ideographs repository](https://github.com/unicode-org/uk-source-ideographs/).","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_USource - IRG sources","ref":"irg_sources.html#kirg_usource"},{"type":"extras","doc":"> The IRG “U” source mapping for this character in decimal. U-source references are a reference into the U-source ideograph database; see [UAX45]. They consist of “UTC” followed by a hyphen and a five-digit, zero-padded index into the database.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kIRG_VSource - IRG sources","ref":"irg_sources.html#kirg_vsource"},{"type":"extras","doc":"> The IRG “V” source mapping for this character in hexadecimal. The IRG “V” source consists of data from the following national standards and lists from Vietnam.\n\n> V0 TCVN 5773:1993\n> V1 TCVN 6056:1995\n> V2 VHN 01:1998\n> V3 VHN 02: 1998\n> V4 Kho Chữ Hán Nôm Mã Hoá (Hán Nôm Coded Character Repertoire), Hà Nội, 2007\n> VN Vietnamese horizontal extensions; the value is its code point","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kRSUnicode - IRG sources","ref":"irg_sources.html#krsunicode"},{"type":"extras","doc":"> The standard radical-stroke count for this character in the form “radical.additional strokes”. The radical is indicated by a number in the range (1..214) inclusive. An apostrophe (') after the radical indicates a simplified version of the given radical. The “additional strokes” value is the residual stroke-count, the count of all strokes remaining after eliminating all strokes associated with the radical.\n\n> This field is also used for additional radical-stroke indices where either a character may be reasonably classified under more than one radical, or alternate stroke count algorithms may provide different stroke counts.\n\n> The residual stroke count may be negative. This is because some characters (for example, U+225A9, U+29C0A) are constructed by removing strokes from a standard radical.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"","title":"kTotalStrokes - IRG sources","ref":"irg_sources.html#ktotalstrokes"},{"type":"extras","doc":"> The total number of strokes in the character (including the radical). When there are two values, then the first is preferred for zh-Hans (CN) and the second is preferred for zh-Hant (TW). When there is only one value, it is appropriate for both.\n\n> The preferred value is the one most commonly associated with the character in modern text using customary fonts.\n\n> This field is targeted specifically for use by CLDR collation and transliteration. As such, it is subject to considerations that help keep pīnyīn-based Han collation (and its tailorings) and transliteration reasonably stable.","title":"Description - IRG sources","ref":"irg_sources.html#description"},{"type":"extras","doc":"","title":"Shape of return - IRG sources","ref":"irg_sources.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - IRG sources","ref":"irg_sources.html#notes"},{"type":"extras","doc":"# Numeric values","title":"Numeric values","ref":"numeric_values.html"},{"type":"extras","doc":"","title":"kAccountingNumeric - Numeric values","ref":"numeric_values.html#kaccountingnumeric"},{"type":"extras","doc":"> The value of the character when used as an accounting numeral to prevent fraud. A numeral such as 十 (ten) is easily transformed into 千 (thousand) by adding a single stroke, so monetary documents often use an accounting form of the numeral, such as 拾 (ten), instead of the more common—and simpler—form. Characters with this property will have a single, well-defined value, which a native reader can reasonably be expected to understand.\n\n> The three numeric-value fields should have no overlap; that is, characters with a `kAccountingNumeric` value should not have a `kOtherNumeric` or `kPrimaryNumeric` value as well.","title":"Description - Numeric values","ref":"numeric_values.html#description"},{"type":"extras","doc":"","title":"Shape of return - Numeric values","ref":"numeric_values.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Numeric values","ref":"numeric_values.html#notes"},{"type":"extras","doc":"","title":"kOtherNumeric - Numeric values","ref":"numeric_values.html#kothernumeric"},{"type":"extras","doc":"> One or more values of the character when used as a numeral. Characters with this property are rarely used for writing numbers, or have non-standard or multiple values depending on the region. For example, 㠪 is a rare character whose meaning, “five,” would not be recognized by most native readers. An English-language equivalent is “gross,” whose numeric value, “one hundred forty-four,” is not universally understood by native readers.\n\n> The three numeric-value fields should have no overlap; that is, characters with a `kOtherNumeric` value should not have a `kAccountingNumeric` or `kPrimaryNumeric` value as well.","title":"Description - Numeric values","ref":"numeric_values.html#description"},{"type":"extras","doc":"","title":"Shape of return - Numeric values","ref":"numeric_values.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Numeric values","ref":"numeric_values.html#notes"},{"type":"extras","doc":"","title":"kPrimaryNumeric - Numeric values","ref":"numeric_values.html#kprimarynumeric"},{"type":"extras","doc":"> The value of the character when used as a numeral. Characters which have this property have numeric values that are common, and always convey the same numeric value. For example, 千 always means “thousand.” A native reader is expected to understand the numeric value for these characters.\n\n> The three numeric-value fields should have no overlap; that is, characters with a `kPrimaryNumeric` value should not have a `kAccountingNumeric` or `kOtherNumeric` value as well.","title":"Description - Numeric values","ref":"numeric_values.html#description"},{"type":"extras","doc":"","title":"Shape of return - Numeric values","ref":"numeric_values.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Numeric values","ref":"numeric_values.html#notes"},{"type":"extras","doc":"# Other mappings","title":"Other mappings","ref":"other_mappings.html"},{"type":"extras","doc":"","title":"kBigFive - Other mappings","ref":"other_mappings.html#kbigfive"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kCCCII - Other mappings","ref":"other_mappings.html#kcccii"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kCNS1986 - Other mappings","ref":"other_mappings.html#kcns1986"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kCNS1992 - Other mappings","ref":"other_mappings.html#kcns1992"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kEACC - Other mappings","ref":"other_mappings.html#keacc"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kGB0 - Other mappings","ref":"other_mappings.html#kgb0"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kGB1 - Other mappings","ref":"other_mappings.html#kgb1"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kGB3 - Other mappings","ref":"other_mappings.html#kgb3"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kGB5 - Other mappings","ref":"other_mappings.html#kgb5"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kGB7 - Other mappings","ref":"other_mappings.html#kgb7"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kGB8 - Other mappings","ref":"other_mappings.html#kgb8"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kHKSCS - Other mappings","ref":"other_mappings.html#khkscs"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kIBMJapan - Other mappings","ref":"other_mappings.html#kibmjapan"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kJa - Other mappings","ref":"other_mappings.html#kja"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kJinmeiyoKanji - Other mappings","ref":"other_mappings.html#kjinmeiyokanji"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kJis0 - Other mappings","ref":"other_mappings.html#kjis0"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kJis1 - Other mappings","ref":"other_mappings.html#kjis1"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kJIS0213 - Other mappings","ref":"other_mappings.html#kjis0213"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kJoyoKanji - Other mappings","ref":"other_mappings.html#kjoyokanji"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kKoreanEducationHanja - Other mappings","ref":"other_mappings.html#kkoreaneducationhanja"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kKoreanName - Other mappings","ref":"other_mappings.html#kkoreanname"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kKPS0 - Other mappings","ref":"other_mappings.html#kkps0"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kKPS1 - Other mappings","ref":"other_mappings.html#kkps1"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kKSC0 - Other mappings","ref":"other_mappings.html#kksc0"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kKSC1 - Other mappings","ref":"other_mappings.html#kksc1"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kMainlandTelegraph - Other mappings","ref":"other_mappings.html#kmainlandtelegraph"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kPseudoGB1 - Other mappings","ref":"other_mappings.html#kpseudogb1"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kTaiwanTelegraph - Other mappings","ref":"other_mappings.html#ktaiwantelegraph"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kTGH - Other mappings","ref":"other_mappings.html#ktgh"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"","title":"kXerox - Other mappings","ref":"other_mappings.html#kxerox"},{"type":"extras","doc":">","title":"Description - Other mappings","ref":"other_mappings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Other mappings","ref":"other_mappings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Other mappings","ref":"other_mappings.html#notes"},{"type":"extras","doc":"# Radical stroke-counts","title":"Radical stroke-counts","ref":"radical_stroke_counts.html"},{"type":"extras","doc":"","title":"kRSAdobe_Japan1_6 - Radical stroke-counts","ref":"radical_stroke_counts.html#krsadobe_japan1_6"},{"type":"extras","doc":"> Information on the glyphs in Adobe-Japan1-6 as contributed by Adobe. The value consists of a number of space-separated entries. Each entry consists of three pieces of information separated by a plus sign:\n\n> 1) C or V. “C” indicates that the Unicode code point maps directly to the Adobe-Japan1-6 CID that appears after it, and “V” indicates that it is considered a variant form, and thus not directly encoded.\n\n> 2) The Adobe-Japan1-6 CID.\n\n> 3) Radical-stroke data for the indicated Adobe-Japan1-6 CID. The radical-stroke data consists of three pieces separated by periods: the Kangxi radical (1-214), the number of strokes in the form the radical takes in the glyph, and the number of strokes in the residue. The standard Unicode radical-stroke form can be obtained by omitting the second value, and the total strokes in the glyph from adding the second and third values.","title":"Description - Radical stroke-counts","ref":"radical_stroke_counts.html#description"},{"type":"extras","doc":"","title":"Shape of return - Radical stroke-counts","ref":"radical_stroke_counts.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Radical stroke-counts","ref":"radical_stroke_counts.html#notes"},{"type":"extras","doc":"","title":"kRSKangXi - Radical stroke-counts","ref":"radical_stroke_counts.html#krskangxi"},{"type":"extras","doc":"> The Kangxi radical-stroke count for this character consistent with the value of the kKangXi field in the form “radical.additional strokes”.","title":"Description - Radical stroke-counts","ref":"radical_stroke_counts.html#description"},{"type":"extras","doc":"","title":"Shape of return - Radical stroke-counts","ref":"radical_stroke_counts.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Radical stroke-counts","ref":"radical_stroke_counts.html#notes"},{"type":"extras","doc":"# Readings","title":"Readings","ref":"readings.html"},{"type":"extras","doc":"","title":"kCantonese - Readings","ref":"readings.html#kcantonese"},{"type":"extras","doc":"> The most customary jyutping (Cantonese) reading for this character.\n\n> This field is targeted specifically for use by CLDR collation and transliteration. As such, it is subject to considerations that help keep jyutping-based Han collation (and its tailorings) and transliteration reasonably stable. The values may not in all cases track the preferred reading in some dictionaries.\n\nThis is an abridged entry.  For sources, see the `kCantonese` [entry](https://www.unicode.org/reports/tr38/#kCantonese) in Annex #38.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kDefinition - Readings","ref":"readings.html#kdefinition"},{"type":"extras","doc":"> An English definition for this character. Definitions are for modern written Chinese and are usually (but not always) the same as the definition in other Chinese dialects or non-Chinese languages. In some cases, synonyms are indicated. Fuller variant information can be found using the various variant fields.\n\n> Definitions specific to non-Chinese languages or Chinese dialects other than modern Mandarin are marked, for example, (Cant.) or (J).\n\n> Major definitions are separated by semicolons, and minor definitions by commas. Any valid Unicode character (except for tab, double-quote, and any line break character) may be used within the definition field.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kHangul - Readings","ref":"readings.html#khangul"},{"type":"extras","doc":"> The modern Korean pronunciation(s) for this character in Hangul, with its source(s) following a colon.\n\n> A value of 0 corresponds to KS X 1001, a value of 1 corresponds to KS X 1002, a value of E corresponds to 한문 교육용 기초 한자 (漢文敎育用基礎漢字), and a value of N corresponds to 인명용 한자 (人名用漢字). A value of X indicates that a K-source was formerly at that code point but was later removed.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kHanyuPinlu - Readings","ref":"readings.html#khanyupinlu"},{"type":"extras","doc":"> The Pronunciations and Frequencies of this character, based in part on those appearing in 《現代漢語頻率詞典》   (XDHYPLCD) [Modern Standard Beijing Chinese Frequency Dictionary] (complete bibliographic information below).\n\n> This dataset contains a total of 3799 records. (The original data provided to Unihan 2003/02/04 contained a total of 3800 records, including 〇 [U+3007] líng ‘IDEOGRAPHIC NUMBER ZERO’, not included in Unihan since it is not a CJK UNIFIED IDEOGRAPH.)\n\n> Each entry is comprised of two pieces of data. The Hanyu Pinyin (HYPY) pronunciation(s) of the character. Immediately following the pronunciation, a numeric string appears in parentheses: for example, in “ā(392)” the numeric string “392” indicates the sum total of the frequencies of the pronunciations of the character as given in HYPLCD.\n\n> Where more than one pronunciation exists, these are sorted by descending frequency, and the list elements are “space” delimited.\n\nThis is an abridged description.  For release information, see the `kHanyuPinlu` [field](https://www.unicode.org/reports/tr38/#kHanyuPinlu) in Annex #38.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kHanyuPinyin - Readings","ref":"readings.html#khanyupinyin"},{"type":"extras","doc":"> The 漢語拼音 Hànyǔ Pīnyīn reading(s) appearing in the edition of 《漢語大字典》 Hànyǔ Dà Zìdiǎn (HDZ) specified in the “kHanYu” property description (q.v.). Each location has the form “ABCDE.XYZ” (as in “kHanYu”); multiple locations for a given pīnyīn reading are separated by commas. The list of locations is followed by a colon, followed by a comma-separated list of one or more pīnyīn readings. Where multiple pīnyīn readings are associated with a given mapping, these are ordered as in HDZ (for the most part reflecting relative commonality). The following are representative records.\n\n> | U+34CE | 㓎 | 10297.260: qīn,qìn,qǐn | | U+34D8 | 㓘 | 10278.080,10278.090: sù | | U+5364 | 卤 | 10093.130: xī,lǔ 74609.020: lǔ,xī | | U+5EFE | 廾 | 10513.110,10514.010,10514.020: gǒng |\n\n> For example, the “kHanyuPinyin” value for 卤 U+5364 is “10093.130: xī,lǔ 74609.020: lǔ,xī”. This means that 卤 U+5364 is found in “kHanYu” at entries 10093.130 and 74609.020. The former entry has the two pīnyīn readings xī and lǔ (in that order), whereas the latter entry has the readings lǔ and xī (reversing the order).\n\n> This data was originally input by 井作恆 Jǐng Zuòhéng, proofed by 聃媽歌 Dān Māgē (Magda Danish, using software donated by 文林 Wénlín Institute, Inc. and tables prepared by 曲理查 Qū Lǐchá), and proofed again and prepared for the Unicode Consortium by 曲理查 Qū Lǐchá (2008-01-14).\n\n> -- Release Notes --\n> This data set includes readings for 34,130 distinct HDZ Hànzì, 34,302 HDZ references, and 1,457 distinct pīnyīn syllables.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kJapaneseKun - Readings","ref":"readings.html#kjapanesekun"},{"type":"extras","doc":"> The Japanese pronunciation(s) of this character in the Hepburn romanization.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kJapaneseOn - Readings","ref":"readings.html#kjapaneseon"},{"type":"extras","doc":"> The Sino-Japanese pronunciation(s) of this character.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kKorean - Readings","ref":"readings.html#kkorean"},{"type":"extras","doc":"> The Korean pronunciation(s) of this character, using the Yale romanization system. (See http://en.wikipedia.org/wiki/Korean_romanization for a discussion of the various Korean romanization systems.)\n\n> Use of the kKorean field is not recommended. The kHangul field, which is aligned to the KS X 1001 and KS X 1002 standards, 한문 교육용 기초 한자 (漢文敎育用基礎漢字), and 인명용 한자 (人名用漢字), is recommended to be used instead.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kMandarin - Readings","ref":"readings.html#kmandarin"},{"type":"extras","doc":">  \tThe most customary pīnyīn reading for this character. When there are two values, then the first is preferred for zh-Hans (CN) and the second is preferred for zh-Hant (TW). When there is only one value, it is appropriate for both.\n\n> This field is targeted specifically for use by CLDR collation and transliteration. As such, it is subject to considerations that help keep pīnyīn-based Han collation (and its tailorings) and transliteration reasonably stable. The values may not in all cases track the preferred use in some dictionaries.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kTang - Readings","ref":"readings.html#ktang"},{"type":"extras","doc":"> The Tang dynasty pronunciation(s) of this character, derived from or consistent with T’ang Poetic Vocabulary by Hugh M. Stimson, Far Eastern Publications, Yale University 1976. An asterisk indicates that the word or morpheme represented in toto or in part by the given character with the given reading occurs more than four times in the seven hundred poems covered.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kTGHZ2013 - Readings","ref":"readings.html#ktghz2013"},{"type":"extras","doc":"> One or more Hànyǔ Pīnyīn readings as given in Tōngyòng Guīfàn Hànzì Zìdiǎn (full bibliographic information below).\n\n> Each pīnyīn reading is preceded by the character’s location(s) in the dictionary, separated from the reading by a colon. Multiple locations for a given reading are separated by commas. Multiple “location: reading” values are separated by a space. Each location reference is of the form /[0-9]{3}\\.[0-9]{3}/. The number preceding the period is the page number, zero-padded to three digits. The first two digits of the number following the period are the entry’s position on the page, zero-padded. The third digit is 0 for a main entry and greater than 0 for a parenthesized or bracketed variant of the main entry. \n\nThis is an abridged description.  For bibliographic information, see the field [entry](https://www.unicode.org/reports/tr38/#kTGHZ2013) in Annex #38.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kVietnamese - Readings","ref":"readings.html#kvietnamese"},{"type":"extras","doc":"> The character’s pronunciation(s) in Quốc ngữ.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"","title":"kXHC1983 - Readings","ref":"readings.html#kxhc1983"},{"type":"extras","doc":">  \tOne or more Hànyǔ Pīnyīn readings as given in the Xiàndài Hànyǔ Cídiǎn (full bibliographic information below).\n\n> Each pīnyīn reading is preceded by the character’s location(s) in the dictionary, separated from the reading by a colon; multiple locations for a given reading are separated by commas; multiple “location: reading” values are separated by a space. Each location reference is of the form /[0-9]{4}\\.[0-9]{3}\\*?/ . The number preceding the period is the page number, zero-padded to four digits. The first two digits of the number following the period are the entry’s position on the page, zero-padded. The third digit is 0 for a main entry and greater than 0 for a parenthesized variant of the main entry. A trailing “*” (asterisk) on the location indicates an encoded variant substituted for an unencoded character (see below).\n\nThis is an abridged description.  For bibliographic information and release notes, see the field [entry](https://www.unicode.org/reports/tr38/#kXHC1983) in Annex #38.","title":"Description - Readings","ref":"readings.html#description"},{"type":"extras","doc":"","title":"Shape of return - Readings","ref":"readings.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Readings","ref":"readings.html#notes"},{"type":"extras","doc":"# Variants","title":"Variants","ref":"variants.html"},{"type":"extras","doc":"","title":"kSemanticVariant - Variants","ref":"variants.html#ksemanticvariant"},{"type":"extras","doc":"> The Unicode value for a semantic variant for this character. A semantic variant is an x- or y-variant with similar or identical meaning which can generally be used in place of the indicated character.\n\n> The basic syntax is a Unicode scalar value. It may optionally be followed by additional data. The additional data is separated from the Unicode scalar value by a less-than sign (<), and may be subdivided itself into substrings by commas, each of which may be divided into two pieces by a colon. The additional data consists of a series of field tags for another field in the Unihan database indicating the source of the information. If these field tags are themselves subdivided by a colon, the final piece is a string consisting of the letters T (for tòng, U+540C 同) B (for bù, U+4E0D 不), Z (for zhèng, U+6B63 正), F (for fán, U+7E41 繁), or J (for jiǎn U+7C21 簡/U+7B80 简).\n\n> T is used if the indicated source explicitly indicates the two are the same (for example, by saying that the one character is “the same as” the other).\n\n> B is used if the source explicitly indicates that the two are used improperly one for the other.\n\n> Z is used if the source explicitly indicates that the given character is the preferred form. Thus, kHanYu indicates that U+5231 刱 and U+5275 創 are semantic variants and that U+5275 創 is the preferred form.\n\n> F is used if the source explicitly indicates that the given character is the traditional form.\n\n> J is used if the source explicitly indicates that the given character is the simplified form.\n\n> Data on simplified and traditional variations can be included in this field to document cases where different sources disagree on the nature of the relationship between two characters. The kSemanticVariant and kSpecializedSemanticVariant fields need not be consulted when interconverting between traditional and simplified Chinese.\n\n> As an example, U+3A17 has the kSemanticVariant value \"U+6377<kHanYu:TZ\". This means that, according to the Hanyu Da Zidian, U+3A17 and U+6377 have identical meaning and that U+6377 is the preferred form.","title":"Description - Variants","ref":"variants.html#description"},{"type":"extras","doc":"","title":"Shape of return - Variants","ref":"variants.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Variants","ref":"variants.html#notes"},{"type":"extras","doc":"","title":"kSimplifiedVariant - Variants","ref":"variants.html#ksimplifiedvariant"},{"type":"extras","doc":">  \tThe Unicode value(s) for the simplified Chinese variant(s) for this character. A full discussion of the kSimplifiedVariant and kTraditionalVariant fields is found in Section 3.7.1 above.\n\n> Much of the data on simplified and traditional variants was graciously supplied by Wenlin Institute, Inc. http://www.wenlin.com.","title":"Description - Variants","ref":"variants.html#description"},{"type":"extras","doc":"","title":"Shape of return - Variants","ref":"variants.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Variants","ref":"variants.html#notes"},{"type":"extras","doc":"","title":"kSpecializedSemanticVariant - Variants","ref":"variants.html#kspecializedsemanticvariant"},{"type":"extras","doc":"> The Unicode value for a specialized semantic variant for this character. The syntax is the same as for the kSemanticVariant field.\n\n> A specialized semantic variant is an x- or y-variant with similar or identical meaning only in certain contexts.","title":"Description - Variants","ref":"variants.html#description"},{"type":"extras","doc":"","title":"Shape of return - Variants","ref":"variants.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Variants","ref":"variants.html#notes"},{"type":"extras","doc":"","title":"kSpoofingVariant - Variants","ref":"variants.html#kspoofingvariant"},{"type":"extras","doc":"> The spoofing variants for the character, if any. Spoofing variants include character pairs which look similar, particularly at small point sizes, which are not already z-variants or compatibility variants. See Section 3.7.3 for a full description of spoofing variants. The syntax consists of the character's code point.","title":"Description - Variants","ref":"variants.html#description"},{"type":"extras","doc":"","title":"Shape of return - Variants","ref":"variants.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Variants","ref":"variants.html#notes"},{"type":"extras","doc":"","title":"kTraditionalVariant - Variants","ref":"variants.html#ktraditionalvariant"},{"type":"extras","doc":"> The Unicode value(s) for the traditional Chinese variant(s) for this character. A full discussion of the kSimplifiedVariant and kTraditionalVariant fields is found in Section 3.7.1 above.\n\n> Much of the data on simplified and traditional variants was graciously supplied by Wenlin Institute, Inc. http://www.wenlin.com.","title":"Description - Variants","ref":"variants.html#description"},{"type":"extras","doc":"","title":"Shape of return - Variants","ref":"variants.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Variants","ref":"variants.html#notes"},{"type":"extras","doc":"","title":"kZVariant - Variants","ref":"variants.html#kzvariant"},{"type":"extras","doc":"> The z-variants for the character, if any. Z-variants are instances where the same abstract shape has been encoded multiple times, either in error or because of source separation. Z-variant pairs also have identical semantics.\n\n> The basic syntax is a Unicode scalar value. It may optionally be followed by additional data. The additional data is separated from the Unicode scalar value by a less-than sign (<), and may be subdivided itself into substrings by commas. The additional data consists of a series of field tags for another field in the Unihan database indicating the source of the information.","title":"Description - Variants","ref":"variants.html#description"},{"type":"extras","doc":"","title":"Shape of return - Variants","ref":"variants.html#shape-of-return"},{"type":"extras","doc":"","title":"Notes - Variants","ref":"variants.html#notes"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}